@@ -14,6 +14,12 @@ use super::*;
 
 impl Cluster {
     const CLUSTER: Emoji<'static, 'static> = Emoji("☸", "*");
+
+    pub(crate) fn all_locations(&self) -> Vec<Location> {
+        let aws = self.locations.aws.iter().map(|aws| aws.region.into());
+        let azure = self.locations.azure.iter().map(|azure| azure.region.into());
+        aws.chain(azure).collect()
+    }
 }
 
 impl fmt::Display for Cluster {
